import logzero
from logzero import logger
import os, json

# Import default vars
from pyutil import defaults
defaults = defaults.logger

home = os.path.expanduser("~")
user_settings_file = os.path.join(home, "pyutil_settings.json")

defaults = dict(defaults)

if os.path.exists(user_settings_file):
    with open(user_settings_file) as file:
        user_defaults = json.load(file)["logger"]
    defaults.update(user_defaults)

class Logger:
    def __init__(self, logfile_path=None, maxBytes=None, backupCount=None):
        """ Sort out the given variables and if neccessary fill in default variables
            or give all parameters:
            from myutil import Logger
            log1 = Logger("/path/to/logfile", maxBytes=1000, backupCount=10)

            Logfile will rotate after reaching maxBytes, default is '0', never rotate
            If rotation enabled, it will keep 'backupCount' files, default is 10
        """

        self.logfile_path = logfile_path if logfile_path is not None else os.path.join(os.path.expanduser("~"), defaults["logfile_path"])
        self.maxBytes = maxBytes if maxBytes is not None else defaults["maxBytes"]
        self.backupCount = backupCount if backupCount is not None else defaults["backupCount"]

        logzero.logfile(self.logfile_path, backupCount=self.backupCount, maxBytes=self.maxBytes, disableStderrLogger=True)
        #formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s');
        #logzero.formatter(formatter)

    def info(self, info):
        logzero.logfile(self.logfile_path)
        logger.info(info)
        return None

    def warning(self, warning):
        logzero.logfile(self.logfile_path)
        logger.warning(warning)
        return None

    def error(self, error):
        logzero.logfile(self.logfile_path)
        logger.error(error)
        return None

    def debug(self, debug):
        logzero.logfile(self.logfile_path)
        logger.debug(debug)
        return None



#!/usr/bin/python3
#-*- coding: utf-8 -*-

import smtplib
import mimetypes
import os, json
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText

# Import default vars
from pyutil import defaults
defaults = defaults.mail

home = os.path.expanduser("~")
user_settings_file = os.path.join(home, "pyutil_settings.json")

defaults = dict(defaults)

if os.path.exists(user_settings_file):
    with open(user_settings_file) as file:
        user_defaults = json.load(file)["mail"]
    defaults.update(user_defaults)

class Mail:
    def __init__(self, sender=None, server=None, port=None, sendfile="None", filepath="None", password="None"):
        """ Sort out the given variables and if neccessary fill in default variables
            or give all parameters:
            from myutil import Mail
            instance = Mail(sender, mailserver, port, true, "/path/to/file", password)
        """

        self.server = server if server is not None else defaults["server"]
        self.port = port if port is not None else defaults["port"]
        self.sendfile = sendfile if sendfile is not "None" else defaults["sendfile"]
        self.filepath = filepath if filepath is not "None" else defaults["filepath"]
        self.sender = sender if sender is not None else defaults["sender"]
        self.password = password if password is not "None" else defaults["password"]

        self.server = smtplib.SMTP(self.server, self.port)
        self.msg = MIMEMultipart()
        # If a password is given, use it to login to the mailserver
        if self.password != "None":
            self.server.starttls()
            self.server.ehlo()
            self.server.login(self.sender, self.password)

        self.msg["From"] = self.sender

        # Check if user wants to send a file, if so read the specified file
        if self.sendfile.lower() == "True":
            fp = open(self.filepath)
            attachment = MIMEText(fp.read())
            fp.close()
            # Attach the file to the message
            self.msg.attach(attachment)

    def send(self, subject, text, receipient):
        """ Send the mail
            Usage:
            instance.send(subject, text, [receipient1, receipent2])
            Or:
            instance.send(subject, text, receipient)
        """

        #.subject = subject
        #self.text = text
        #self.receipient = receipient

        # Set subject to mail
        self.msg["Subject"]  = subject

        # Set actual text of the email
        #body = text
        self.msg.attach(MIMEText(text, "plain"))

        # If given receipients is a list object cycle through list of receipients
        if type(receipient) == list:
            for email in receipient:
                # Set receipient in email header
                self.msg["To"] = email
                # Built the massage object
                message = self.msg.as_string()

                # Try to send mail
                try:
                    self.server.sendmail(self.sender, email, message)
                    self.server.quit()
                    print("Success: Sent email \""+subject+"\" from \""+self.sender+"\" to \""+email+"\"")
                except:
                    print("Error: Unable to send email \""+subject+"\" from \""+self.sender+"\" to \""+email+"\"")

        # If given receipients is not a list, just try to send the mail
        else:
            email = receipient
            # Set receipient in email header
            self.msg["To"] = email
            # Built the massage object
            message = self.msg.as_string()

            try:
                self.server.sendmail(self.sender, email, message)
                self.server.quit()
                print("Success: Sent email \""+subject+"\" from \""+self.sender+"\" to \""+email+"\"")
            except Exception as e:
                print("Error: Unable to send email \""+subject+"\" from \""+self.sender+"\" to \""+email+"\"")
                raise e



#!/usr/bin/python3
#-*- coding: utf-8 -*-
from ldap3 import Server, Connection
import sys, os, json

# Import default vars
from pyutil import defaults
defaults = defaults.ldap

home = os.path.expanduser("~")
user_settings_file = os.path.join(home, "pyutil_settings.json")

defaults = dict(defaults)

if os.path.exists(user_settings_file):
    with open(user_settings_file) as file:
        user_defaults = json.load(file)["ldap"]
    defaults.update(user_defaults)

class Ldap:
    def __init__(self, user, password, server=None):
        """ Sort out the given variables and if neccessary fill in default variables

        Usage:
        Modify defaults in the class and use the minumum parameters:
        from pyutil import Ldap
        instance = Ldap(username, password)

        or give all parameters:
        instance = Ldap(username, password, server)
        """
        self.user = user
        self.password = password

        self.server = server if server is not None else defaults["server"]

        server = Server(self.server, use_ssl=True)
        self.__conn__ = Connection(server, self.user, self.password, auto_bind=True)

    def query(self, search_value, search_attribute=None, return_attributes=None, dn=None,):
        """Do the ldap query with the given variables

        Usage:
        result = instance.query(searchvalue, search_attribute return_attributes, dn)

        "search_value" is  the value to match to the ldap object, usually "firstname.lastname@example.org"
        "search_attribute" is the ldap attribute to match the "match_value" to, defaults to "userPrincipalName"
        "return_attributes" is a list of attributes you want to retrieve, for instance ["pwdlastset", "lastlogon"]
        "dn" is the tree you want to start the search in, usually similar to "OU=OrgUnit,DC=example,DC=org"
        """
        self.dn = dn if dn is not None else defaults["dn"]
        self.return_attributes = return_attributes if return_attributes is not None else defaults["return_attributes"]
        self.search_attribute = search_attribute if search_attribute is not None else defaults["search_attribute"]


        self.__conn__.search(self.dn,'(&('+search_attribute+'='+search_value+'))', attributes=self.return_attributes)
        response = json.loads(self.__conn__.response_to_json())
        #status, result, response, _ = conn.search(dn, '(objectClass=inetOrgPerson)', search_scope=SUBTREE)  # usually you don't need the original request (4th element of the returned tuple)
        return response["entries"][0]["attributes"]


ldap = {
    "server": "example.org",
    "search_attribute": "userPrincipalName",
    "dn": "OU=OrgUnit,DC=example,DC=org",
    "return_attributes": ["lastlogon"],
}

mail = {
    "server": "mailserver.example.org",
    "port": 25,
    "sendfile": "False",
    "filepath": "None",
    "sender": "no-reply@example.org",
    "password": "None",
}

logger = {
    "logfile_path": "pyutil.log",
    "maxBytes": 0,
    "backupCount": 10,
}
